@@ -1,5 +1,6 @@
 import os
 import sys
+import pprint
 from ..common import prettyllog
 import subprocess
 
@@ -15,11 +16,19 @@ def main():
 
     # change to the ui directory
     VIR_ENV = os.environ.get("VIRTUAL_ENV", "/opt/ign8")
-    os.chdir(VIR_ENV/ + "/lib/python3.9/site-packages/ign8/ui/project/ignite")
+    os.chdir(VIR_ENV + "/lib/python3.9/site-packages/ign8/ui/project/ignite")
+
+    print(os.getcwd())
+    print(os.listdir())
+
 
     # run the server
-    myserver = subprocess.run(["gunicon", "--bind", ign8_ui_host + ":" + ign8_ui_port, "--workers", "3", "ignite.wsgi -c gunicorn.conf.py --log-level=debug"])
-    myserver.wait()
+    # python manage.py runserver
+
+    myserver = subprocess.run(["gunicorn", "--bind", ign8_ui_host + ":" + ign8_ui_port, "--workers", "3", "ignite.wsgi -c gunicorn.conf.py --log-level=debug"])
+
+    pprint.pprint(myserver) 
+
     return 0
 
 
